pub struct TripQueryItem<'__w, '__s> {
pub entity: <Entity as QueryData>::Item<'__w, '__s>,
pub vehicles: <&'static TripVehicles as QueryData>::Item<'__w, '__s>,
pub name: <&'static Name as QueryData>::Item<'__w, '__s>,
pub class: <&'static TripClass as QueryData>::Item<'__w, '__s>,
pub schedule: <&'static TripSchedule as QueryData>::Item<'__w, '__s>,
/* private fields */
}Expand description
Automatically generated [WorldQuery](:: bevy :: ecs::query::WorldQuery) item type for TripQuery, returned when iterating over query results.
Fields
entity: <Entity as QueryData>::Item<'__w, '__s>vehicles: <&'static TripVehicles as QueryData>::Item<'__w, '__s>name: <&'static Name as QueryData>::Item<'__w, '__s>class: <&'static TripClass as QueryData>::Item<'__w, '__s>schedule: <&'static TripSchedule as QueryData>::Item<'__w, '__s>Implementations
Sourceimpl<'w, 's> TripQueryItem<'w, 's>
impl<'w, 's> TripQueryItem<'w, 's>
Sourcepub fn duration<'a>(
&self,
q: &Query<'a, 'a, &EntryEstimate>,
) -> Option<Duration>
pub fn duration<'a>( &self, q: &Query<'a, 'a, &EntryEstimate>, ) -> Option<Duration>
The duration of the trip, from the first entry’s arrival time to the last entry’s departure time. This method only checks the first and last entries’ times, hence any intermediate entries are not considered.
pub fn stroke<'a>( &self, q: &Query<'a, 'a, &DisplayedStroke, With<Class>>, ) -> DisplayedStroke